/* $Id: print_headers.h,v 1.4 2010-03-29 05:44:31 rikster5 Exp $ */

/*******************************************************************************
 * print_headers.h
 * A module of J-Pilot http://jpilot.org
 *
 * Copyright (C) 2001 by Colin Brough
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 ******************************************************************************/

void print_common_prolog(FILE *f);
void print_common_setup(FILE *f);
void print_common_header(FILE *f);
void print_week_header(FILE *f);
void print_month_header(FILE *f);
void print_day_header(FILE *f);
void print_todo_header(FILE *f);
